/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * ============================================
 *
 * Copyright (C) 2007-2010 by Tidalwave s.a.s.
 * Project home page: http://openbluesky.kenai.com
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: MultiAspect.java,v f674db3214d3 2010/02/13 21:51:06 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.aspect;

import javax.annotation.Nonnull;
import java.util.Collection;

/***********************************************************************************************************************
 *
 * @author Fabrizio Giudici
 * @version $Id: MultiAspect.java,v f674db3214d3 2010/02/13 21:51:06 fabrizio $
 *
 **********************************************************************************************************************/
class MultiAspect extends Aspect
  {
    @Nonnull
    private final Collection<Aspect> aspects;

    public MultiAspect (final @Nonnull Collection<Aspect> aspects)
      {
        this.aspects = aspects;
      }

    @Override
    protected void handleException (final @Nonnull Throwable t)
      {
        for (final @Nonnull Aspect aspect : aspects)
          {
            aspect.handleException(t);
          }
      }

    @Override
    protected void runAfter()
      {
        for (final @Nonnull Aspect aspect : aspects)
          {
            aspect.runAfter();
          }
      }

    @Override
    protected void runBefore()
      {
        for (final @Nonnull Aspect aspect : aspects)
          {
            aspect.runBefore();
          }
      }

    @Override
    protected void runFinally()
      {
        for (final @Nonnull Aspect aspect : aspects)
          {
            aspect.runFinally();
          }
      }
  }
